#!/bin/bash
#
#    Program : check_cpu_top
#            :
#     Author : Florian COULOMBEL
#            :
#    Purpose : Nagios plugin to return the state of CPU 
#            :
# Parameters : --help
#            : --version
#            : -w
#            : -c
#            :
#    Returns : Standard Nagios status_* codes as defined in utils.sh
#            :
#      Notes :
#============:==============================================================
#        0.0 : 19/05/2005
#            : Initial coding
#            :

#
# Shamelessly stolen from other Nagios plugins.
#
PROGNAME=`basename $0`
PROGPATH=`echo $0 | /bin/sed -e 's,[\\/][^\\/][^\\/]*$,,'`
REVISION=`echo '$Revision: 0.0 $' | sed -e 's/[^0-9.]//g'`


. $PROGPATH/utils.sh

print_usage() {
    echo "Usage: $PROGNAME"
    echo "$0  -w warning -c critical 
    me>"
    echo " $0 (-v | --version)"
    echo " $0 (-h | --help)"
}



print_help() {
    print_revision $PROGNAME $REVISION
    echo ""
    print_usage
    echo ""
    echo "This plugin checks CPU load."
    echo ""
    support
    exit 0
}

if [ "$1" = "-v" -o "$1" = "--version" ]
    then
        #elp_version
    exit 3
fi
if [ "$1" = "-h" -o "$1" = "--help" ]
    then
    print_help
    exit 3
fi

# Test of the command lines arguments
wt=""
ct=""
while test $# -gt 0
  do
  case "$1" in
      -w|--warning)
      if [ -n "$wt" ]
	  then
	  echo "Only one --warning argument needed... Trying to test bad things ? :-)"
	  help_usage
	  exit 3
      fi
      shift
      wt=$1
      ;;
      -c|--critical)
      if [ -n "$ct" ]
	  then
	  echo "Only one --critical argument needed... Trying to test bad things ?:-)"
	  help_usage
	  exit 3
      fi
      shift
      ct=$1
      ;;
  esac
  shift
done
tmp=`top -n 1 | grep total | awk '{print $8}' | awk -F , '{print $1}'`
value=`expr 100 - $tmp` 

#finally Inform Nagios of what we found...

if [ $value -gt $ct ]
    then
    echo "CRITICAL - CPU usage $value "
    exit 2
elif [ $value -gt $wt ]
    then
    echo "WARNING -  CPU usage $value "
    exit 1
else
    echo "OK -  CPU usage $value "
    exit 0
fi